Bug 571907 - Base package should include logger

Start building for Java 16's release.
Also include jdk.zipfs in minimal (so that JDT fully works).
diff --git a/releng/org.eclipse.justj.releng/Jenkinsfile b/releng/org.eclipse.justj.releng/Jenkinsfile
index cff7f45..bdc07f9 100644
--- a/releng/org.eclipse.justj.releng/Jenkinsfile
+++ b/releng/org.eclipse.justj.releng/Jenkinsfile
@@ -122,16 +122,38 @@
   PROMOTE: 'true'
 ]
 
+def java16 = [
+  label: 'Java 16 (test)',
+  BUILD_DESCRIPTION: 'Build jdk.java.net Java 16 (-test)',
+  PUBLISH_LOCATION_PREFIX: "${testPrefix}",
+  JUSTJ_MANIFEST_URL: "${justjURL}/${testPrefix}/15/downloads/latest/justj.manifest",
+  JDK_URLS_WINDOWS: '''
+    https://download.java.net/java/GA/jdk16/7863447f0ab643c585b9bdebf67c69db/36/GPL/openjdk-16_windows-x64_bin.zip
+    ''',
+  JDK_URLS_MACOS: '''
+    https://download.java.net/java/GA/jdk16/7863447f0ab643c585b9bdebf67c69db/36/GPL/openjdk-16_osx-x64_bin.tar.gz
+    ''',
+  JDK_URLS_LINUX: '''
+    https://download.java.net/java/GA/jdk16/7863447f0ab643c585b9bdebf67c69db/36/GPL/openjdk-16_linux-x64_bin.tar.gz
+    ''',
+  JDK_URLS_LINUX_AARCH64: '''
+    https://download.java.net/java/GA/jdk16/7863447f0ab643c585b9bdebf67c69db/36/GPL/openjdk-16_linux-aarch64_bin.tar.gz
+    ''',
+  BUILD_TYPE: 'nightly',
+  PROMOTE: 'true'
+]
+
 def parambuilds = [
   java11,
   java11Extra,
   java14,
   java14Extra,
-  java15
+  java15,
+  java16
 ]
 
-def javaDefault = update(java15, [
-    BUILD_DESCRIPTION: 'Build jdk.java.net Java 15',
+def javaDefault = update(java16, [
+    BUILD_DESCRIPTION: 'Build jdk.java.net Java 16',
     PUBLISH_LOCATION_PREFIX: "${defaultPrefix}",
     JUSTJ_MANIFEST_URL: "${justjURL}/${defaultPrefix}/15/downloads/latest/justj.manifest"
   ])
diff --git a/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator With Local Rsync.launch b/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator With Local Rsync.launch
index c7bc03c..25e67e0 100644
--- a/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator With Local Rsync.launch
+++ b/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator With Local Rsync.launch
@@ -19,8 +19,8 @@
         <listEntry value="org.eclipse.debug.ui.launchGroup.run"/>
     </listAttribute>
     <booleanAttribute key="org.eclipse.jdt.launching.ATTR_USE_START_ON_FIRST_THREAD" value="true"/>
-    <stringAttribute key="org.eclipse.jdt.launching.JRE_CONTAINER" value="org.eclipse.jdt.launching.JRE_CONTAINER/org.eclipse.jdt.internal.debug.ui.launcher.StandardVMType/JavaSE-1.8"/>
-    <stringAttribute key="org.eclipse.jdt.launching.PROGRAM_ARGUMENTS" value="-os ${target.os} -ws ${target.ws} -arch ${target.arch} -nl ${target.nl} -consoleLog&#13;&#10;-retain 5&#13;&#10;-label &quot;JustJ JREs&quot;&#13;&#10;-build-url https://ci.eclipse.org/justj/job/build-jres/&#13;&#10;-root ${project_loc:org.eclipse.justj.model}/jre-gen/releng/org.eclipse.justj.site/target&#13;&#10;-relative jres/${string_prompt:&quot;Java Major Version&quot;:14}/updates&#13;&#10;-super jres&#13;&#10;-version-iu org.eclipse.justj.&#13;&#10;-commit https://git.eclipse.org/c/justj/justj.git/commit/?id=b5a713a8cabf4a382535485d0643d11fffffad0a&#13;&#10;-promote ${project_loc:org.eclipse.justj.model}/jre-gen/releng/org.eclipse.justj.site/target/repository&#13;&#10;-remote localhost:${system_property:user.home}/justj&#13;&#10;-timestamp ${current_date:yyyyMMddHHmm}&#13;&#10;-type ${string_prompt:&quot;Build Type&quot;:nightly}&#13;&#10;-breadcrumb &quot;JustJ https://www.eclipse.org/justj/?page=downloads&quot;&#13;&#10;-breadcrumb JREs&#13;&#10;-favicon https://www.eclipse.org/justj/justj_favicon.ico&#13;&#10;-title-image https://www.eclipse.org/justj/justj_title.svg&#13;&#10;-body-image https://www.eclipse.org/justj/justj.svg"/>
+    <stringAttribute key="org.eclipse.jdt.launching.JRE_CONTAINER" value="org.eclipse.jdt.launching.JRE_CONTAINER/org.eclipse.jdt.internal.debug.ui.launcher.StandardVMType/JavaSE-11"/>
+    <stringAttribute key="org.eclipse.jdt.launching.PROGRAM_ARGUMENTS" value="-os ${target.os} -ws ${target.ws} -arch ${target.arch} -nl ${target.nl} -consoleLog&#13;&#10;-retain 5&#13;&#10;-label &quot;JustJ JREs&quot;&#13;&#10;-build-url https://ci.eclipse.org/justj/job/build-jres/&#13;&#10;-root ${project_loc:org.eclipse.justj.model}/jre-gen/releng/org.eclipse.justj.site/target&#13;&#10;-relative jres/${string_prompt:&quot;Java Major Version&quot;:15}/updates&#13;&#10;-super jres&#13;&#10;-version-iu org.eclipse.justj.&#13;&#10;-commit https://git.eclipse.org/c/justj/justj.git/commit/?id=b5a713a8cabf4a382535485d0643d11fffffad0a&#13;&#10;-promote ${project_loc:org.eclipse.justj.model}/jre-gen/releng/org.eclipse.justj.site/target/repository&#13;&#10;-remote localhost:${system_property:user.home}/justj&#13;&#10;-timestamp ${current_date:yyyyMMddHHmm}&#13;&#10;-type ${string_prompt:&quot;Build Type&quot;:nightly}&#13;&#10;-breadcrumb &quot;JustJ https://www.eclipse.org/justj/?page=downloads&quot;&#13;&#10;-breadcrumb JREs&#13;&#10;-favicon https://www.eclipse.org/justj/justj_favicon.ico&#13;&#10;-title-image https://www.eclipse.org/justj/justj_title.svg&#13;&#10;-body-image https://www.eclipse.org/justj/justj.svg"/>
     <stringAttribute key="org.eclipse.jdt.launching.SOURCE_PATH_PROVIDER" value="org.eclipse.pde.ui.workbenchClasspathProvider"/>
     <stringAttribute key="pde.version" value="3.3"/>
     <stringAttribute key="product" value="org.eclipse.sdk.ide"/>
diff --git a/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator.launch b/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator.launch
index a27d0df..1325883 100644
--- a/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator.launch
+++ b/releng/org.eclipse.justj.releng/JustJ JREs Update Site Generator.launch
@@ -19,7 +19,7 @@
         <listEntry value="org.eclipse.debug.ui.launchGroup.run"/>
     </listAttribute>
     <booleanAttribute key="org.eclipse.jdt.launching.ATTR_USE_START_ON_FIRST_THREAD" value="true"/>
-    <stringAttribute key="org.eclipse.jdt.launching.JRE_CONTAINER" value="org.eclipse.jdt.launching.JRE_CONTAINER/org.eclipse.jdt.internal.debug.ui.launcher.StandardVMType/JavaSE-1.8"/>
+    <stringAttribute key="org.eclipse.jdt.launching.JRE_CONTAINER" value="org.eclipse.jdt.launching.JRE_CONTAINER/org.eclipse.jdt.internal.debug.ui.launcher.StandardVMType/JavaSE-11"/>
     <stringAttribute key="org.eclipse.jdt.launching.PROGRAM_ARGUMENTS" value="-os ${target.os} -ws ${target.ws} -arch ${target.arch} -nl ${target.nl} -consoleLog&#13;&#10;-retain 5&#13;&#10;-label &quot;JustJ JREs&quot;&#13;&#10;-build-url https://ci.eclipse.org/justj/job/build-jres/&#13;&#10;-root ${project_loc:org.eclipse.justj.model}/jre-gen/releng/org.eclipse.justj.site/target&#13;&#10;-relative jres/updates&#13;&#10;-version-iu org.eclipse.justj.&#13;&#10;-commit https://git.eclipse.org/c/justj/justj.git/commit/?id=b5a713a8cabf4a382535485d0643d11fffffad0a&#13;&#10;-promote ${project_loc:org.eclipse.justj.model}/jre-gen/releng/org.eclipse.justj.site/target/repository&#13;&#10;-timestamp ${current_date:yyyyMMddHHmm}&#13;&#10;-type nightly&#13;&#10;-breadcrumb &quot;JustJ https://www.eclipse.org/justj/?page=downloads&quot;&#13;&#10;-breadcrumb JREs&#13;&#10;-favicon https://www.eclipse.org/justj/justj_favicon.ico&#13;&#10;-title-image https://www.eclipse.org/justj/justj_title.svg&#13;&#10;-body-image https://www.eclipse.org/justj/justj.svg"/>
     <stringAttribute key="org.eclipse.jdt.launching.SOURCE_PATH_PROVIDER" value="org.eclipse.pde.ui.workbenchClasspathProvider"/>
     <stringAttribute key="pde.version" value="3.3"/>
diff --git a/releng/org.eclipse.justj.releng/build-jre.sh b/releng/org.eclipse.justj.releng/build-jre.sh
index f0ed08b..387ee8d 100755
--- a/releng/org.eclipse.justj.releng/build-jre.sh
+++ b/releng/org.eclipse.justj.releng/build-jre.sh
@@ -80,8 +80,8 @@
     # We deliberately want to split on space because a URL should not have spaces.
     urls=$@
   else
-    # Default to Java 15 Open JDK.
-    urls="https://download.java.net/java/GA/jdk15.0.2/0d1cfde4252546c6931946de8db48ee2/7/GPL/openjdk-15.0.2$jdk_suffix"
+    # Default to Java 16 Open JDK.
+    urls="https://download.java.net/java/GA/jdk16/7863447f0ab643c585b9bdebf67c69db/36/GPL/openjdk-16$jdk_suffix"
   fi
 fi
 
@@ -100,7 +100,7 @@
 
 # Download an os-specific version of Eclipse.
 #
-eclipse_url="https://download.eclipse.org/eclipse/downloads/drops4/R-4.17-202009021800/eclipse-SDK-4.17$eclipse_suffix"
+eclipse_url="https://download.eclipse.org/eclipse/downloads/drops4/R-4.19-202103031800/eclipse-SDK-4.19$eclipse_suffix"
 eclipse_file=${eclipse_url##*/}
 
 if [ ! -f $eclipse_file ]; then
@@ -144,7 +144,7 @@
 # Remove the incubator modules.
 #
 all_modules=$($jdk/$jdk_relative_bin_folder/java --list-modules | sed "s/@.*//g" | grep -v "jdk.incubator" | tr '\n' ',' | sed 's/,$//')
-simrel_modules="java.base,java.compiler,java.datatransfer,java.desktop,java.instrument,java.logging,java.management,java.naming,java.prefs,java.rmi,java.scripting,java.security.jgss,java.security.sasl,java.sql,java.sql.rowset,java.xml,jdk.crypto.ec,jdk.jdi,jdk.management,jdk.unsupported,jdk.xml.dom"
+simrel_modules="java.base,java.compiler,java.datatransfer,java.desktop,java.instrument,java.logging,java.management,java.naming,java.prefs,java.rmi,java.scripting,java.security.jgss,java.security.sasl,java.sql,java.sql.rowset,java.xml,jdk.crypto.ec,jdk.jdi,jdk.management,jdk.unsupported,jdk.xml.dom,jdk.zipfs"
 installer_modules="java.base,java.desktop,java.logging,java.management,java.naming,java.prefs,java.security.jgss,java.sql,java.xml,jdk.xml.dom,jdk.unsupported"
 
 
@@ -206,15 +206,15 @@
 
 "$vendor_prefix.jre.base"
   "JRE Base"
-  "Provides the minimal modules needed to launch Equinox without reflection warnings."
-  java.base,java.xml,jdk.unsupported,jdk.jdwp.agent
+  "Provides the minimal modules needed to launch Equinox with logging and without reflection warnings."
+  java.base,java.logging,java.xml,jdk.unsupported,jdk.jdwp.agent
   "--compress=2"
   filter
 
 "$vendor_prefix.jre.base.stripped"
   "JRE Base Stripped"
-  "Provides the minimal modules needed to launch Equinox without reflection warnings, stripped of debug information."
-  java.base,java.xml,jdk.unsupported
+  "Provides the minimal modules needed to launch Equinox with logging and without reflection warnings, stripped of debug information."
+  java.base,java.logging,java.xml,jdk.unsupported
   "--compress=2 $strip_debug"
   false